import * as AWS from 'aws-sdk';
import { ILogger } from 'typescript-ilogger';
import { BaseClass } from 'typescript-helper-functions';
import { ISQSHelper } from './interface';
/**
 * SQS Helper
 */
export declare class SQSHelper extends BaseClass implements ISQSHelper {
    /**
     * AWS Repository for SQS
     */
    Repository: AWS.SQS;
    /**
     * Initializes new instance of SQSHelper
     * @param logger {ILogger} Injected logger
     * @param repository {AWS.SQS} Injected Repository. A new repository will be created if not supplied
     * @param options {AWS.SQS.ClientConfiguration} Injected configuration if a Repository is supplied
     */
    constructor(logger: ILogger, repository?: AWS.SQS, options?: AWS.SQS.ClientConfiguration);
    CreateQueueAsync(queueName: string, attributes: AWS.SQS.QueueAttributeMap): Promise<AWS.SQS.CreateQueueResult>;
    DeleteMessageAsync(queueUrl: string, receiptHandle: string): Promise<object>;
    DeleteMessagesAsync(queueUrl: string, receiptHandles: string[]): Promise<AWS.SQS.DeleteMessageBatchResult>;
    DeleteQueueAsync(queueUrl: string): Promise<object>;
    GetNumberOfMessagesOnQueueAsync(queueUrl: string): Promise<number>;
    GetQueueAttributesAsync(queueUrl: string): Promise<AWS.SQS.QueueAttributeMap>;
    PurgeQueueAsync(queueUrl: string): Promise<object>;
    ReceiveAllMessagesAsync(queueUrl: string, visibilityTimeout?: number, attributeNames?: string[], messageAttributeNames?: string[]): Promise<AWS.SQS.Message[]>;
    ReceiveMessagesAsync(queueUrl: string, maxNumberOfMessages?: number, visibilityTimeout?: number, attributeNames?: string[], messageAttributeNames?: string[]): Promise<AWS.SQS.ReceiveMessageResult>;
    SendMessageAsync(queueUrl: string, messageBody: string, delaySeconds?: number, messageAttributes?: AWS.SQS.MessageBodyAttributeMap): Promise<AWS.SQS.SendMessageResult>;
    SendMessagesAsync(queueUrl: string, entries: AWS.SQS.SendMessageBatchRequestEntry[]): Promise<AWS.SQS.SendMessageBatchResult>;
}
