"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.SQSMock = void 0;
const typescript_helper_functions_1 = require("typescript-helper-functions");
// tslint:disable-next-line: no-var-requires
const AWS = require('aws-sdk');
/**
 * SQS Mock class
 */
class SQSMock extends typescript_helper_functions_1.BaseMock {
    constructor() {
        super(...arguments);
        /**
         * Mocks an AWS.SQS.CreateQueueResult response
         */
        this.CreateQueueResult = {};
        /**
         * Mocks an AWS.SQS.DeleteMessageOutput response
         * Technically doesn't exist
         */
        this.DeleteMessageOutput = {};
        /**
         * Mocks an AWS.SQS.DeleteMessageBatchResult response
         */
        this.DeleteMessageBatchResult = { Failed: [], Successful: [] };
        /**
         * Mocks an AWS.SQS.DeleteQueueResult response
         * Technically doesn't exist
         */
        this.DeleteQueueResult = {};
        /**
         * Mocks an AWS.SQS.DeleteMessageBatchResult response
         */
        this.GetQueueAttributesResult = { Attributes: { ApproximateNumberOfMessages: '5' } };
        /**
         * Mocks an AWS.SQS.PurgeQueueResult response
         * Technically doesn't exist
         */
        this.PurgeQueueResult = {};
        /**
         * Mocks an AWS.SQS.ReceiveMessageResult
         */
        this.ReceiveMessageResult = { Messages: [] };
        /**
         * Mocks an AWS.SQS.SendMessageResult
         */
        this.SendMessageResult = {};
        /**
         * Mocks an AWS.SQS.SendMessageBatchResult
         */
        this.SendMessageBatchResult = { Failed: [], Successful: [] };
    }
    /**
     * Create the SQS mock
     */
    CreateMock(returnError) {
        const rejectResponse = new Error(`AWS Error`);
        // implement the AWS responses
        const awsResponses = {
            // create queue response
            createQueue: {
                promise: jest.fn().mockImplementation(() => {
                    return returnError ?
                        Promise.reject(rejectResponse) :
                        Promise.resolve(this.CreateQueueResult);
                }),
            },
            // delete message response
            deleteMessage: {
                promise: jest.fn().mockImplementation(() => {
                    return returnError ?
                        Promise.reject(rejectResponse) :
                        Promise.resolve(this.DeleteMessageOutput);
                }),
            },
            // delete messages response
            deleteMessageBatch: {
                promise: jest.fn().mockImplementation(() => {
                    return returnError ?
                        Promise.reject(rejectResponse) :
                        Promise.resolve(this.DeleteMessageBatchResult);
                }),
            },
            // delete queue response
            deleteQueue: {
                promise: jest.fn().mockImplementation(() => {
                    return returnError ?
                        Promise.reject(rejectResponse) :
                        Promise.resolve(this.DeleteQueueResult);
                }),
            },
            // get queue attributes response
            getQueueAttributes: {
                promise: jest.fn().mockImplementation(() => {
                    return returnError ?
                        Promise.reject(rejectResponse) :
                        Promise.resolve(this.GetQueueAttributesResult);
                }),
            },
            // purge queue response
            purgeQueue: {
                promise: jest.fn().mockImplementation(() => {
                    return returnError ?
                        Promise.reject(rejectResponse) :
                        Promise.resolve(this.PurgeQueueResult);
                }),
            },
            // receive message response
            receiveMessage: {
                promise: jest.fn().mockImplementation(() => {
                    return returnError ?
                        Promise.reject(rejectResponse) :
                        Promise.resolve(this.ReceiveMessageResult);
                }),
            },
            // send message response
            sendMessage: {
                promise: jest.fn().mockImplementation(() => {
                    return returnError ?
                        Promise.reject(rejectResponse) :
                        Promise.resolve(this.SendMessageResult);
                }),
            },
            // send messages response
            sendMessageBatch: {
                promise: jest.fn().mockImplementation(() => {
                    return returnError ?
                        Promise.reject(rejectResponse) :
                        Promise.resolve(this.SendMessageBatchResult);
                }),
            },
        };
        // create the functions
        let functions = new AWS.SQS();
        functions = {
            createQueue: () => awsResponses.createQueue,
            deleteMessage: () => awsResponses.deleteMessage,
            deleteMessageBatch: () => awsResponses.deleteMessageBatch,
            deleteQueue: () => awsResponses.deleteQueue,
            getQueueAttributes: () => awsResponses.getQueueAttributes,
            purgeQueue: () => awsResponses.purgeQueue,
            receiveMessage: () => awsResponses.receiveMessage,
            sendMessage: () => awsResponses.sendMessage,
            sendMessageBatch: () => awsResponses.sendMessageBatch,
        };
        return functions;
    }
}
exports.SQSMock = SQSMock;
//# sourceMappingURL=mock.js.map